==> haskell-hledger-lib-1.10-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hledger-lib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-lib
version: 1.10
id: hledger-lib-1.10-5qc9eby1iyW8kpKE8PCo1B
key: hledger-lib-1.10-5qc9eby1iyW8kpKE8PCo1B
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Core data types, parsers and functionality for the hledger accounting tools
description:
    This is a reusable library containing hledger'\''s core functionality.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
abi: 43e03ad09a61794ab0e6ed6e18f1b172
exposed: True
exposed-modules:
    Hledger Hledger.Data Hledger.Data.Account Hledger.Data.AccountName
    Hledger.Data.Amount Hledger.Data.AutoTransaction
    Hledger.Data.Commodity Hledger.Data.Dates Hledger.Data.Journal
    Hledger.Data.Ledger Hledger.Data.MarketPrice Hledger.Data.Period
    Hledger.Data.Posting Hledger.Data.RawOptions
    Hledger.Data.StringFormat Hledger.Data.Timeclock
    Hledger.Data.Transaction Hledger.Data.Types Hledger.Query
    Hledger.Read Hledger.Read.Common Hledger.Read.CsvReader
    Hledger.Read.JournalReader Hledger.Read.TimeclockReader
    Hledger.Read.TimedotReader Hledger.Reports
    Hledger.Reports.BalanceHistoryReport Hledger.Reports.BalanceReport
    Hledger.Reports.BudgetReport Hledger.Reports.EntriesReport
    Hledger.Reports.MultiBalanceReports Hledger.Reports.PostingsReport
    Hledger.Reports.ReportOptions Hledger.Reports.ReportTypes
    Hledger.Reports.TransactionsReports Hledger.Utils
    Hledger.Utils.Color Hledger.Utils.Debug Hledger.Utils.Parse
    Hledger.Utils.Regex Hledger.Utils.String Hledger.Utils.Test
    Hledger.Utils.Text Hledger.Utils.Tree Hledger.Utils.UTF8IOCompat
    Text.Tabular.AsciiWide
hidden-modules: Text.Megaparsec.Custom Paths_hledger_lib
import-dirs: /usr/lib/ghc-8.4.3/site-local/hledger-lib-1.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/hledger-lib-1.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hledger-lib-1.10
hs-libraries: HShledger-lib-1.10-5qc9eby1iyW8kpKE8PCo1B
depends:
    Decimal-0.5.1-EbccLDw0IaW1LFAy4Wdwk
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc array-0.5.2.0
    base-4.11.1.0 base-compat-batteries-0.10.1-LLh6zuxO9A0GhuBNRjv95y
    blaze-markup-0.8.2.2-DLsNA1WKDw36RR9ku6FlST bytestring-0.10.8.2
    cmdargs-0.10.20-DuSx78jNQymI404wla4i2p containers-0.5.11.0
    csv-0.1.2-EpTL7zD0nY4Lq2oA3vrN2m
    data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn deepseq-1.4.3.0
    directory-1.3.1.5 extra-1.6.12-DHdLvf94bhcHifO5HapwCI
    filepath-1.4.2 hashtables-1.2.3.1-FwvkrjNnnglEJJXpMCqokg
    megaparsec-6.5.0-444ZVg94OsgBECw8zur7LD mtl-2.2.2
    old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu parsec-3.1.13.0
    parser-combinators-1.0.0-FkDIkMqlFRy3ywBA26Y9ci
    pretty-show-1.8.2-KRA90Zl1RBkEqIFTMdr4WM
    regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
    tabular-0.2.2.7-HF2IJKR6TJrGdD2ud3QwlY text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0 uglymemo-0.1.0.1-L9PTRXpxSIOFxxvyPl9dNx
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
abi-depends: Decimal-0.5.1-EbccLDw0IaW1LFAy4Wdwk=d8f2d6dfcdbe01da2b06aaff890178a1
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc=ac560d64fefa05d8067fac44b9aaa9de
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-batteries-0.10.1-LLh6zuxO9A0GhuBNRjv95y=5587f60ad32ffc1f6a8671336ccb43fe
             blaze-markup-0.8.2.2-DLsNA1WKDw36RR9ku6FlST=73c07c7dc173d95a5dd0d6c0058f8bb4
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cmdargs-0.10.20-DuSx78jNQymI404wla4i2p=5eb128502fee539d8b5665038e95d326
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             csv-0.1.2-EpTL7zD0nY4Lq2oA3vrN2m=96eb36dad3db736296feabfd6b1391a1
             data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn=02e9419e0e877fc1db7c56d6f64866aa
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             extra-1.6.12-DHdLvf94bhcHifO5HapwCI=36b397877b0e54ac8d0c415a92aec365
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             hashtables-1.2.3.1-FwvkrjNnnglEJJXpMCqokg=9716e82ce2a1119e069e6c69de7a6cc9
             megaparsec-6.5.0-444ZVg94OsgBECw8zur7LD=8b94ebb799b881d9cbb836d1782929fe
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu=cfb34821984e3d96e729b0bde52e0e35
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             parser-combinators-1.0.0-FkDIkMqlFRy3ywBA26Y9ci=7f9925423ee321de0651ba5e24e000f1
             pretty-show-1.8.2-KRA90Zl1RBkEqIFTMdr4WM=fe1c8cd990a59160567f7942ed9f9a72
             regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K=98feb6ae4c5e833326f77c1995f4743b
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=cdf77c47c599317cfa01d2d98185c5d3
             tabular-0.2.2.7-HF2IJKR6TJrGdD2ud3QwlY=406988501480082666ba7a2896144d5e
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             uglymemo-0.1.0.1-L9PTRXpxSIOFxxvyPl9dNx=84f3e38ea85acc39cbd16676bfc5e427
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
haddock-interfaces: /usr/share/doc/haskell-hledger-lib/html/hledger-lib.haddock
haddock-html: /usr/share/doc/haskell-hledger-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hledger-lib-1.10-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hledger-lib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-lib
version: 1.10
id: hledger-lib-1.10-BHNAlHMTTUcZMia6XPqu0
key: hledger-lib-1.10-BHNAlHMTTUcZMia6XPqu0
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Core data types, parsers and functionality for the hledger accounting tools
description:
    This is a reusable library containing hledger'\''s core functionality.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
abi: 7189448655b01b6bdf93438ad58b7223
exposed: True
exposed-modules:
    Hledger Hledger.Data Hledger.Data.Account Hledger.Data.AccountName
    Hledger.Data.Amount Hledger.Data.AutoTransaction
    Hledger.Data.Commodity Hledger.Data.Dates Hledger.Data.Journal
    Hledger.Data.Ledger Hledger.Data.MarketPrice Hledger.Data.Period
    Hledger.Data.Posting Hledger.Data.RawOptions
    Hledger.Data.StringFormat Hledger.Data.Timeclock
    Hledger.Data.Transaction Hledger.Data.Types Hledger.Query
    Hledger.Read Hledger.Read.Common Hledger.Read.CsvReader
    Hledger.Read.JournalReader Hledger.Read.TimeclockReader
    Hledger.Read.TimedotReader Hledger.Reports
    Hledger.Reports.BalanceHistoryReport Hledger.Reports.BalanceReport
    Hledger.Reports.BudgetReport Hledger.Reports.EntriesReport
    Hledger.Reports.MultiBalanceReports Hledger.Reports.PostingsReport
    Hledger.Reports.ReportOptions Hledger.Reports.ReportTypes
    Hledger.Reports.TransactionsReports Hledger.Utils
    Hledger.Utils.Color Hledger.Utils.Debug Hledger.Utils.Parse
    Hledger.Utils.Regex Hledger.Utils.String Hledger.Utils.Test
    Hledger.Utils.Text Hledger.Utils.Tree Hledger.Utils.UTF8IOCompat
    Text.Tabular.AsciiWide
hidden-modules: Text.Megaparsec.Custom Paths_hledger_lib
import-dirs: /usr/lib/ghc-8.4.3/site-local/hledger-lib-1.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/hledger-lib-1.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hledger-lib-1.10
hs-libraries: HShledger-lib-1.10-BHNAlHMTTUcZMia6XPqu0
depends:
    Decimal-0.5.1-EbccLDw0IaW1LFAy4Wdwk
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc array-0.5.2.0
    base-4.11.1.0 base-compat-batteries-0.10.1-LLh6zuxO9A0GhuBNRjv95y
    blaze-markup-0.8.2.2-DLsNA1WKDw36RR9ku6FlST bytestring-0.10.8.2
    cmdargs-0.10.20-DuSx78jNQymI404wla4i2p containers-0.5.11.0
    csv-0.1.2-EpTL7zD0nY4Lq2oA3vrN2m
    data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn deepseq-1.4.3.0
    directory-1.3.1.5 extra-1.6.12-DHdLvf94bhcHifO5HapwCI
    filepath-1.4.2 hashtables-1.2.3.1-FwvkrjNnnglEJJXpMCqokg
    megaparsec-6.5.0-444ZVg94OsgBECw8zur7LD mtl-2.2.2
    old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu parsec-3.1.13.0
    parser-combinators-1.0.0-FkDIkMqlFRy3ywBA26Y9ci
    pretty-show-1.8.2-4CWdOLjOoVl3kwNutDWHFu
    regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
    tabular-0.2.2.7-HF2IJKR6TJrGdD2ud3QwlY text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0 uglymemo-0.1.0.1-L9PTRXpxSIOFxxvyPl9dNx
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
abi-depends: Decimal-0.5.1-EbccLDw0IaW1LFAy4Wdwk=d8f2d6dfcdbe01da2b06aaff890178a1
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             ansi-terminal-0.8.1-72nCTUZRZdJG8ztHzhbgjc=ac560d64fefa05d8067fac44b9aaa9de
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-batteries-0.10.1-LLh6zuxO9A0GhuBNRjv95y=5587f60ad32ffc1f6a8671336ccb43fe
             blaze-markup-0.8.2.2-DLsNA1WKDw36RR9ku6FlST=73c07c7dc173d95a5dd0d6c0058f8bb4
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             cmdargs-0.10.20-DuSx78jNQymI404wla4i2p=5eb128502fee539d8b5665038e95d326
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             csv-0.1.2-EpTL7zD0nY4Lq2oA3vrN2m=96eb36dad3db736296feabfd6b1391a1
             data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn=02e9419e0e877fc1db7c56d6f64866aa
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             extra-1.6.12-DHdLvf94bhcHifO5HapwCI=36b397877b0e54ac8d0c415a92aec365
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             hashtables-1.2.3.1-FwvkrjNnnglEJJXpMCqokg=9716e82ce2a1119e069e6c69de7a6cc9
             megaparsec-6.5.0-444ZVg94OsgBECw8zur7LD=8b94ebb799b881d9cbb836d1782929fe
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu=cfb34821984e3d96e729b0bde52e0e35
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             parser-combinators-1.0.0-FkDIkMqlFRy3ywBA26Y9ci=7f9925423ee321de0651ba5e24e000f1
             pretty-show-1.8.2-4CWdOLjOoVl3kwNutDWHFu=2f1e3850a2b84883fdac57bdd8ddd497
             regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K=98feb6ae4c5e833326f77c1995f4743b
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=cdf77c47c599317cfa01d2d98185c5d3
             tabular-0.2.2.7-HF2IJKR6TJrGdD2ud3QwlY=406988501480082666ba7a2896144d5e
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             uglymemo-0.1.0.1-L9PTRXpxSIOFxxvyPl9dNx=84f3e38ea85acc39cbd16676bfc5e427
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
haddock-interfaces: /usr/share/doc/haskell-hledger-lib/html/hledger-lib.haddock
haddock-html: /usr/share/doc/haskell-hledger-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
